@@ -19,7 +19,7 @@ import threading
 import queue
 import re
 
-def write2path(lines,path='',encoding='utf-8',method='lines',append='w',wrap=False):
+def write2path(lines,path='',encoding='utf-8',method='lines',append='w',wrap=True):
     """ 写入数组到本地文件
         lines - 字符串数组
         path - 本地文件路径
@@ -51,7 +51,7 @@ def append2path(line,path,encoding='utf-8',method='line',append='a'):
         else:
             fw.writelines(line)
 
-def read_path(path,method='lines',encoding='utf-8',errors='strict',strip=False):
+def read_path(path,method='lines',encoding='utf-8',errors='strict',strip=True):
     """ 读取文件
             path - 本地文件路径
             method - 读取类型 (lines-以多行数据读取 line-以单个字符串读取)
@@ -196,7 +196,7 @@ def getfilesize(filePath):
     fsize = fsize / (1000 * 1000)
     return round(fsize, 2)
 
-def listDir(rootDir,only_file=False,only_folder=False,recursive=False):
+def listDir(rootDir,only_file=False,only_folder=False,recursive=False,sort=True):
     """ 获取文件夹中的文件列表 """
     list_filepath = []
     if recursive:
@@ -228,7 +228,10 @@ def listDir(rootDir,only_file=False,only_folder=False,recursive=False):
                     list_filepath.append(pathname)
                 continue
             list_filepath.append(pathname)
-    return list_filepath
+    if sort:
+        return list(sorted(list_filepath))
+    else:
+        return list_filepath
 
 def makedir(dir_path,delete_exists=False):
     """ 创建文件夹 """
@@ -264,7 +267,7 @@ def copyfile(origin_path, target_path):
 
 def movefile(origin_path, target_path):
     """ 移动文件 """
-    if os.path.isfile(origin_path):
+    if os.path.exists(origin_path):
         shutil.move(origin_path, target_path)
     else:
         print("--------移动文件失败:" + origin_path + ",路径不存在--------")
